<?php
/***************************************************************************
 *  Copyright (C) 2007 Michel Teddy
 *  This file is part of Tagadash
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published
 *  by the Free Software Foundation; either version 2.1 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 ***************************************************************************/
/***************************************************************************
 *  Fichier : /systeme/lib_php4/db_odbc.php
 *  Date de création : 04/09/2007
 *  Dernière modification : 14/09/2007
 ***************************************************************************/

// Sécurité
if ( !defined ( 'TAGADASH' ) )
{
    header ( 'Location: ../' );
    die ( -1 );
}


// Inclusion du fichier de la classe Database
if ( is_file ( 'systeme/lib_php4/database.' . EXT ) )
{
    include_once ( 'systeme/lib_php4/database.' . EXT );
}
else
{
    die ( 'Le fichier systeme/lib_php4/database.' . EXT . ' est introuvable.' );
}


/*
 * Méthodes publiques de la classe Database :
 *
 *  Database ( void )
 *  void SetParametres ( string $Hote , string $User , string $Pass , string $Base = '' , string $Pref = '' )
 *
 * Méthodes publiques de la classe fille :
 *
 *  ODBC ( void )
 *  Destructeur ( void )
 *
 *  bool Connect ( void )
 *  bool Disconnect ( void )
 *  void Erreur ( unsigned int $ligne , string $fichier , string $requete )
 *  ressource Requete ( string $requete )
 *  unsigned int LastInsertId ( ressource $requete )
 *  unsigned int NbrRowsSelected ( ressource $requete )
 *  unsigned int NbrRowsAffected ( ressource $requete )
 *  array Result ( ressource $requete , string $champ , int $ligne = 0 )
 *  array ResultArray ( ressource $requete )
 *  string Protege ( string $texte , bool $stripslashes = true )
 *  string Version ( void )
 *
 **/


class ODBC extends Database
{
    /*****************************************
     * ODBC->ODBC ( void )
     *
     * Constructeur de la classe.
     * Modifie les paramètres et se connecte à la base de données
     ****************************************/

    function ODBC ()
    {
        parent::Database ();

        $this->Connect ();
    }


    /*****************************************
     * ODBC->Destructeur ()
     *
     * Déstructeur de la classe.
     * Se déconnecte du serveur
     ****************************************/

    function Destructeur ()
    {
        $this->Disconnect ();
    }


    /*****************************************
     * bool ODBC->Connect ( void )
     *
     * Connexion à la base de données
     *
     *  Retour : booléen indiquant le succès de l'opération
     ****************************************/

    function Connect ()
    {
        $id = odbc_connect ( $this->hote , $this->user , $this->pass );

        if ( $id == false )
        {
            return false;
        }

        $this->link = $id;

        if ( !mysql_select_db ( $this->base , $this->link ) )
        {
            if ( !odbc_exec ( $this->link , "CREATE DATABASE `" . $this->base . "`;" ) )
            {
                return false;
            }
        }

        $this->connected = true;

        return true;
    }


    /*****************************************
     * bool ODBC->Disconnect ( void )
     *
     * Déconnexion de la base de données
     *
     *  Retour : booléen indiquant le succès de l'opération
     ****************************************/

    function Disconnect ()
    {
        if ( $this->connected )
        {
            $this->connected = false;
            $this->connected_tmp = false;
            $this->link = 0;

            return odbc_close ( $this->link );
        }

        return false;
    }


    /*****************************************
     * void ODBC->Erreur ( unsigned int $ligne , string $fichier , string $requete )
     *
     * Affichage d'une erreur
     *
     *  $ligne : ligne du fichier où s'effectue la requête (obtenue par __LINE__)
     *  $fichier : fichier où s'effectue la requête (obtenue par __FILE__)
     *  $requete : requête SQL exécutée
     ****************************************/

    function Erreur ( $ligne , $fichier , $requete )
    {
        global $configuration;
        global $site;

        $page_titre = 'Erreur ODBC';
        $page_simple = 1;


        // On enlève les espaces en début de ligne
        $requete = preg_replace ( "#\n(\s{0,})#" , "\n" , $requete );

        // Pour la coloration de la requête SQL
        if ( function_exists ( geshi_highlight ) )
        {
            $requete = geshi_highlight ( $requete , 'mysql' , null , true );
        }

        // Suppression des retours à la ligne
        #$requete = preg_replace ( "#\n#" , " " , $requete );


        $page_texte = "<p><strong>Erreur :</strong> " . odbc_errormsg ( $this->link ) . " (Erreur " . odbc_error ( $this->link ) . ")</p>\n";
        $page_texte .= '<p><strong>Date et heure :</strong> ' . date ( $configuration['format_date'] ) . ' à ' . date ( $configuration['format_heure'] ) . "</p>\n";
        $page_texte .= "<p><strong>Fichier :</strong> " . $fichier . " (Ligne " . $ligne . ")</p>\n";
        $page_texte .= "<p><strong>Requête SQL :</strong></p>\n<div id=\"query\"><code>" . $requete . "</code></div>\n";

        $page_texte .= "<p>Retour à la <a href=\"index." . EXT . "\" title=\"Retourner sur la page d'accueil\">page d'accueil</a>.</p>";

        include ( 'systeme/page.' . EXT );

        die ( -1 );
    }


    /*****************************************
     * ressource ODBC->Requete ( string $requete )
     *
     * Exécute une requête SQL
     *
     *  $requete : requête SQL à exécuter
     *
     *  Retour : résultat de la requête ou false en cas d'échec
     ****************************************/

    function Requete ( $requete )
    {
        if ( !$this->connected )
        {
            return false;
        }

        // Temps d'exécution
        $tps_requetes = microtime ( true );

        $req = odbc_exec ( $this->link , $requete );

        $this->tps_requetes += microtime ( true ) - $tps_requetes;
        $this->nbr_requetes++;

        return $req;
    }


    /*****************************************
     * unsigned int ODBC->LastInsertId ( ressource $requete )
     *
     * Dernier identifiant entré dans la base
     *
     *  $requete : requête concernée
     *
     *  Retour : numéro du dernier id entré dans la base
     ****************************************/

    function LastInsertId ( $requete )
    {
        return 0;
    }


    /*****************************************
     * unsigned int ODBC->NbrRowsSelected ( ressource $requete )
     *
     * Compte le nombre de lignes sélectionnées par une requête Select.
     *
     *  $requete : requête à analyser
     *
     *  Retour : nombre de ligne sélectionnées
     ****************************************/

    function NbrRowsSelected ( $requete )
    {
        return odbc_num_rows ( $requete );
    }


    /*****************************************
     * unsigned int ODBC->NbrRowsAffected ( ressource $requete )
     *
     * Compte le nombre de lignes affectées par une requête de type Update ou Delete.
     *
     *  $requete : requête à analyser
     *
     *  Retour : nombre de ligne affectées par une requêtes
     ****************************************/

    function NbrRowsAffected ( $requete )
    {
        return odbc_num_rows ( $this->link );
    }

    /*****************************************
     * array ODBC->Result ( ressource $requete , string $champ , unsigned int $ligne = 0 )
     *
     * Retourne le résultat d'une requête Select
     *
     *  $requete : requête à analyser
     *  $champ : champ à sélectionner
     *  $ligne : ligne à sélectionner
     *
     *  Retour : nombre de ligne affectées par une requêtes
     ****************************************/

    function Result ( $requete , $champ , $ligne = 0 )
    {
        for ( $i = 0 ; $row = $this->ResultArray ( $requete ) ; $i++ )
        {
            if ( $ligne === $i ) return $row[$champ];
        }
    }


    /*****************************************
     * array ODBC->ResultArray ( ressource $requete )
     *
     * Retourne le résultat d'une requête Select sous forme de tableau.
     *
     *  $requete : requête à analyser
     *
     *  Retour : nombre de ligne affectées par une requêtes
     ****************************************/

    function ResultArray ( $requete )
    {
        return odbc_fetch_array ( $requete );
    }


    /*****************************************
     * string ODBC->Protege ( string $texte , bool $stripslashes = true )
     *
     * Protège du texte contre les injections SQL
     *
     *  $texte : texte à transformer
     *  $stripslashes : indique si on doit supprimer les slashes
     *
     *  Retour : texte transformé
     ****************************************/

    function Protege ( $texte , $stripslashes = true )
    {
        /*if ( $stripslashes && get_magic_quotes_gpc () == 1 )
        {
            $texte = stripslashes ( $texte );
        }*/

        return $texte;
    }


    /*****************************************
     * string ODBC->Version ( void )
     *
     * Donne la version du serveur
     *
     *  Retour : version du serveur
     ****************************************/

    function Version ()
    {
        return 0;
    }
}

?>