<?php
/***************************************************************************
 *  Copyright (C) 2007 Michel Teddy
 *  This file is part of Tagadash
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published
 *  by the Free Software Foundation; either version 2.1 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 ***************************************************************************/
/***************************************************************************
 *  Fichier : /systeme/lib_php4/fonctions.php
 *  Date de création : 04/09/2007
 *  Dernière modification : 09/09/2007
 ***************************************************************************/

// Sécurité
if ( !defined ( 'TAGADASH' ) )
{
    header ( 'Location: ../' );
    die ( -1 );
}


class Site
{
    /*****************************************
     * bool CreateMiniature ( unsigned int $image , string $extension , unsigned int $taille = 200 )
     *
     * Crée la miniature d'une image et l'enregistre
     *
     *  $image : nom de l'image
     *  $extension : extension de l'image
     *  $taille : taille de la miniature comprise entre 20 et 800
     *
     *  Retour : booléen indiquant le succès de l'opération
     ****************************************/

    function CreateMiniature ( $image , $extension , $taille = 200 )
    {
        // On change la casse de l'extension en minuscule
        $extension = strtolower ( $extension );

        // On appelle la fonction appropriée
        if ( $extension == 'jpg' || $extension == 'jpeg' )
        {
            $source = ImageCreateFromJPEG ( 'fichiers/' . $image . '.jpg' );
        }
        else if ( $extension == 'gif' )
        {
            $source = ImageCreateFromGIF ( 'fichiers/' . $image . '.gif');
        }
        else if ( $extension == 'png' )
        {
            $source = ImageCreateFromPNG ( 'fichiers/' . $image . '.png' );
        }
        else if ( $extension == 'bmp' )
        {
            $source = ImageCreateFromWBMP ( 'fichiers/' . $image . '.png' );
        }
        else
        {
            return false;
        }

        // Largeur et la hauteur de l'image source
        $largeur = ImagesX ( $source );
        $hauteur = ImagesY ( $source );

        // On limite la taille de l'image
        if ( $taille < 20 ) $taille = 20;
        if ( $taille > 800 ) $taille = 800;

        // On regarde si l'image est plus haute que large ou l'inverse
        if ( $largeur < $hauteur )
        {
            // Il est inutile de crée une miniature
            if ( $hauteur <= $taille )
            {
                return false;
            }
            else
            {
                $destination = ImageCreateTrueColor ( $taille * $largeur / $hauteur , $taille );

                // On crée la miniature
                ImageCopyreSampled ( $destination , $source , 0 , 0 , 0 , 0 , $taille * $largeur / $hauteur , $taille , $largeur , $hauteur );
            }
        }
        else
        {
            // Il est inutile de crée une miniature
            if ( $largeur <= $taille )
            {
                return false;
            }
            else
            {
                $destination = ImageCreateTrueColor ( $taille , $taille * $hauteur / $largeur );

                // On crée la miniature
                ImageCopyreSampled ( $destination , $source , 0 , 0 , 0 , 0 , $taille , $taille * $hauteur / $largeur , $largeur , $hauteur );
            }
        }

        // On enregistre la miniature

        if ( $extension == 'jpg' )
        {
            $source = ImageJPEG ( $destination , 'fichiers/thumbs/' . $taille . 'px-' . $image  . '.jpg' );
        }
        else if ( $extension == 'jpeg' )
        {
            $source = ImageJPEG ( $destination , 'fichiers/thumbs/' . $taille . 'px-' . $image  . '.jpeg' );
        }
        else if ( $extension == 'gif' )
        {
            $source = ImageGIF ( $destination , 'fichiers/thumbs/' . $taille . 'px-' . $image . '.gif' );
        }
        else if ( $extension == 'png' )
        {
            $source = ImagePNG ( $destination , 'fichiers/thumbs/' . $taille . 'px-' . $image . '.png' );
        }
        else if ( $extension == 'bmp' )
        {
            $source = ImageWBMP ( $destination , 'fichiers/thumbs/' . $taille . 'px-' . $image . '.bmp' );
        }

        return true;
    }


    /*****************************************
     * string GenerePassword ( unsigned int $longueur = 8 )
     *
     * Génère un mot de passe aléatoirement
     *
     *  $longueur : longueur du mot de passe comprise entre 2 et 32
     *
     *  Retour : mot de passé généré ou false en cas d'échec
     ****************************************/

    function GenerePassword ( $longueur = 8 )
    {
        if ( $longueur < 2 || $longueur > 32 )
        {
            return false;
        }

        // Liste des caractères possibles
        $tableau = array ( 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z',
            '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '!', '?', ':', '/', '§', '#', '=', ';', '_', ',', '.', 'é', 'è', 'à', '@', 'ç', '*', '+');

        $mdp = '';

        // On génère un nouveau mot de passe de 8 caractères
        for ( $i = 0 ; $i < $longueur ; $i++ )
        {
            $mdp = $mdp . $tableau[array_rand ( $tableau )];
        }

        return $mdp;
    }


    /*****************************************
     * string FormSelect ( array $options , int/string $value_selected = false )
     *
     * Crée un champ de formulaire de type Select en sélectionnant une des options
     *
     *  $options : liste des options (option => valeur)
     *  $value_selected : champ à sélectionner
     *
     *  Retour : liste des options sous la forme suivante :
     *  '  <option value="%1"{ selected="selected"}>%2</option>\n'
     ****************************************/

    function FormSelect ( $options , $value_selected = false )
    {
        $chaine = '';

        reset ( $options );

        while ( list ( $option , $valeur ) = each ( $options ) )
        {
            $chaine .= '  <option value="' . $valeur . '"';

            // On est obligé de vérifier le type de $value_selected car on pourrait mettre une chaine valant 'false'
            if ( $value_selected !== false && $value_selected == $valeur && !isset ( $selected ) )
            {
                $chaine .= ' selected="selected"';

                // Pour ne sélectionner qu'une seule option
                $selected = 0;
            }

            $chaine .= '>' . $option . "</option>\n";
        }

        return $chaine;
    }


    /*****************************************
     * string Site->Parser ( string $texte , unsigned int $niveau = 0 )
     *
     * Transforme le texte
     *
     *  $texte : texte à transformer
     *  $niveau : balises autorisées (0, 1 ou 2)
     *
     *  Retour : texte transformé
     ****************************************/

    function Parser ( $texte , $niveau = 0 )
    {
        if ( empty ( $texte ) )
        {
            return "\n";
        }
        else
        {
            $time = time ();

            ////////////////////
            // Transformation des balises
            ////////////////////
            switch ( $niveau )
            {
                // Une partie des balises sont autorisées
                default:
                case 0:

                    // Au cas où on essayerait de contourner la protection
                    $texte = preg_replace ( "#@@TED-" . $time . "-(.+)@@#sU" , "@@TED_" . $time . "-$1@@" , $texte );

                    // On protège les balises autorisées
                    $texte = preg_replace ( "#\<(/?)(code|couleur|citation|police|taille|flottant|position|gras|italique|barre|souligne|titre2|titre3|attention|information|question|erreur|indice|exposant|liste|puce|image|lien|email)\>#sU" , "@@TED-" . $time . "-$1$2@@" , $texte );
                    $texte = preg_replace ( "#\<(code type=(.+)|citation nom=(.+)|liste type=(.+)|image titre=(.+)|couleur nom=(.+)|lien titre=(.+)|email nom=(.+)|position valeur=(.+)|flottant valeur=(.+)|taille valeur=(.+)|police nom=(.+))\>#sU" , "@@TED-" . $time . "-$1@@" , $texte );

                    // On remplace tous les chevrons
                    $texte = str_replace ( '<' , '&lt;' , $texte);
                    $texte = str_replace ( '>' , '&gt;' , $texte);

                    // On remet en forme les balises autorisées
                    $texte = preg_replace ( "#@@TED-" . $time . "-(.+)@@#sU" , "<$1>" , $texte );

                    break;

                // Toutes les balises sont autorisées
                case 1:

                    // Au cas où on essayerait de contourner la protection
                    $texte = preg_replace ( "#@@TED-" . $time . "-(.+)@@#sU" , "@@TED_" . $time . "-$1@@" , $texte );

                    // On protège les balises autorisées
                    $texte = preg_replace ( "#\<(/?)(code|couleur|citation|police|taille|flottant|position|gras|italique|barre|souligne|titre2|titre3|titre4|titre5|titre6|attention|information|question|erreur|indice|exposant|liste|puce|image|lien|email)\>#sU" , "@@TED-" . $time . "-$1$2@@" , $texte );
                    $texte = preg_replace ( "#\<(code type=(.+)|citation nom=(.+)|liste type=(.+)|image titre=(.+)|couleur nom=(.+)|lien titre=(.+)|email nom=(.+)|position valeur=(.+)|flottant valeur=(.+)|taille valeur=(.+)|police nom=(.+))\>#sU" , "@@TED-" . $time . "-$1@@" , $texte );

                    // On remplace tous les chevrons
                    $texte = str_replace ( '<' , '&lt;' , $texte );
                    $texte = str_replace ( '>' , '&gt;' , $texte );
    
                    // On remet en forme les balises autorisées
                    $texte = preg_replace ( "#@@TED-" . $time . "-(.+)@@#U" , "<$1>" , $texte );

                    break;

                // Toutes les balises et le HTML sont autorisés
                case 2:
                    break;
            }

            ////////////////////
            // Conversion des retours à la ligne
            ////////////////////
            $texte = preg_replace ( "#\r\n#" , "\n" , $texte );
            $texte = preg_replace ( "#\n\r#" , "\n" , $texte );
            $texte = preg_replace ( "#\r#" , "\n" , $texte );

            ////////////////////
            // Gras
            ////////////////////
            $texte = preg_replace ( "#<gras>(.+)</gras>#sU" , "<strong>$1</strong>" , $texte );

            ////////////////////
            // Italique
            ////////////////////
            $texte = preg_replace ( "#<italique>(.+)</italique>#sU" , "<em>$1</em>" , $texte );

            ////////////////////
            // Souligné
            ////////////////////
            $texte = preg_replace ( "#<souligne>(.+)</souligne>#sU" , "<span class=\"souligne\">$1</span>" , $texte );

            ////////////////////
            // Barré
            ////////////////////
            $texte = preg_replace ( "#<barre>(.+)</barre>#sU" , "<span class=\"barre\">$1</span>" , $texte );

            ////////////////////
            // Citation
            ////////////////////
            $texte = str_replace ( '<citation>' , '<citation nom="">' , $texte );

            $texte = preg_replace ( "#<citation nom=\"(.{0,})\">(.{0,})<citation nom=\"(.{0,})\">(.{0,})<citation nom=\"(.{0,})\">(.+)</citation>(.{0,})</citation>(.{0,})</citation>#sU" , "<span class=\"citation\">$1</span><div class=\"citationtexte\">$2<span class=\"citation\">$3</span><div class=\"citationtexte\">$4<span class=\"citation\">$5</span><div class=\"citationtexte\">$6</div>$7</div>$8</div>", $texte);
            $texte = preg_replace ( "#<citation nom=\"(.{0,})\">(.{0,})<citation nom=\"(.{0,})\">(.+)</citation>(.{0,})</citation>#sU" , "<span class=\"citation\">$1</span><div class=\"citationtexte\">$2<span class=\"citation\">$3</span><div class=\"citationtexte\">$4</div>$5</div>", $texte);
            $texte = preg_replace ( "#<citation nom=\"(.{0,})\">(.+)</citation>#isU" , "<span class=\"citation\">$1</span><div class=\"citationtexte\">$2</div>", $texte);

            $texte = str_replace ( '<span class="citation"></span>' , '<span class="citation">Citation</span>' , $texte );

            ////////////////////
            // Liste
            ////////////////////
            $texte = preg_replace ( "#<liste>(\s{0,})\n#U" , "<liste>" , $texte );
            $texte = preg_replace ( "#\n(\s{0,})</liste>#U" , "</liste>" , $texte );
            $texte = preg_replace ( "#</puce>(\s{0,})\n#U" , "</puce>" , $texte );
            $texte = preg_replace ( "#\n(\s{0,})<puce>#U" , "<puce>" , $texte );

            $texte = preg_replace ( "#<liste>(.+)</liste>#sU" , "<ul>$1</ul>" , $texte );
            $texte = preg_replace ( "#<liste type=\"1\">(.+)</liste>#sU" , "<ol class=\"liste_1\">$1</ol>" , $texte );
            $texte = preg_replace ( "#<liste type=\"i\">(.+)</liste>#sU" , "<ol class=\"liste_i\">$1</ol>" , $texte );
            $texte = preg_replace ( "#<liste type=\"I\">(.+)</liste>#sU" , "<ol class=\"liste_I\">$1</ol>" , $texte );
            $texte = preg_replace ( "#<liste type=\"a\">(.+)</liste>#sU" , "<ol class=\"liste_a\">$1</ol>" , $texte );
            $texte = preg_replace ( "#<liste type=\"A\">(.+)</liste>#sU" , "<ol class=\"liste_A\">$1</ol>" , $texte );

            $texte = preg_replace ( "#<puce>(.+)</puce>#sU" , "  <li>$1</li>" , $texte );

            ////////////////////
            // Image
            ////////////////////
            $texte = preg_replace ( "#<image>(.+)</image>#U" , "<img src=\"$1\" alt=\"$1\" />" , $texte );
            $texte = preg_replace ( "#<image titre=\"(.+)\">(.+)</image>#U" , "<img src=\"$2\" alt=\"$2\" title=\"$1\" />" , $texte );

            ////////////////////
            // Lien
            ////////////////////
            $texte = preg_replace ( "#<lien>(.+)</lien>#U" , "<a href=\"$1\">$1</a>" , $texte );
            $texte = preg_replace ( "#<lien titre=\"(.+)\">(.+)</lien>#U" , "<a href=\"$2\" title=\"$1\">$1</a>" , $texte );

            ////////////////////
            // Adresse e-mail
            ////////////////////
            $texte = preg_replace ( "#<email>(.+)</email>#U" , "<a href=\"mailto:$1\">$1</a>" , $texte );
            $texte = preg_replace ( "#<email nom=\"(.+)\">(.+)</email>#U" , "<a href=\"mailto:$2\" title=\"$2\">$1</a>" , $texte );

            ////////////////////
            // Titres
            ////////////////////
            $texte = preg_replace ( "#<titre2>(.+)</titre2>#U" , "<h2>$1</h2>" , $texte );
            $texte = preg_replace ( "#<titre3>(.+)</titre3>#U" , "<h3>$1</h3>" , $texte );
            $texte = preg_replace ( "#<titre4>(.+)</titre4>#U" , "<h4>$1</h4>" , $texte );
            $texte = preg_replace ( "#<titre5>(.+)</titre5>#U" , "<h5>$1</h5>" , $texte );
            $texte = preg_replace ( "#<titre6>(.+)</titre6>#U" , "<h6>$1</h6>" , $texte );

            ////////////////////
            // Remarques
            ////////////////////
            $texte = preg_replace ( "#<attention>(.+)</attention>#sU" , "<div class=\"attention\">$1</div>" , $texte );
            $texte = preg_replace ( "#<information>(.+)</information>#sU" , "<div class=\"information\">$1</div>" , $texte );
            $texte = preg_replace ( "#<erreur>(.+)</erreur>#sU" , "<div class=\"erreur\">$1</div>" , $texte );
            $texte = preg_replace ( "#<question>(.+)</question>#sU" , "<div class=\"question\">$1</div>" , $texte );

            ////////////////////
            // Position
            ////////////////////
            $texte = preg_replace ( "#<position valeur=\"(justifie|gauche|centre|droite)\">(.+)</position>#sU" , "<div class=\"$1\">$2</div>" , $texte );

            $texte = preg_replace ( "#<flottant valeur=\"(gauche|droite)\">(.+)</flottant>#sU" , "<div class=\"flot_$1\">$2</div>" , $texte );

            ////////////////////
            // Acronymes
            ////////////////////
            $texte = preg_replace ( "#<acronyme titre=\"(.+)\" langue=\"(.+)\">(.+)</acronyme>#U" , "<acronym title=\"$1\" lang=\"$2\">$3</acronym>", $texte );
            $texte = preg_replace ( "#<acronyme titre=\"(.+)\">(.+)</acronyme>#U" , "<acronym title=\"$1\">$2</acronym>" , $texte );

            ////////////////////
            // Taille
            ////////////////////
            $texte = preg_replace ( "#<taille valeur=\"(ttpetit|tpetit|petit|gros|tgros|ttgros)\">(.+)</taille>#sU" , "<span class=\"$1\">$2</span>" , $texte );

            ////////////////////
            // Polices
            ////////////////////
            $texte = preg_replace ( "#<police nom=\"(optima|geneva|impact|courrier|arial|times)\">(.+)</police>#sU" , "<span class=\"$1\">$2</span>" , $texte );

            ////////////////////
            // Indice et exposant
            ////////////////////
            $texte = preg_replace ( "#<indice>(.+)</indice>#sU" , "<sub>$1</sub>" , $texte );
            $texte = preg_replace ( "#<exposant>(.+)</exposant>#sU" , "<sup>$1</sup>" , $texte );

            ////////////////////
            // Couleur
            ////////////////////
            $texte = preg_replace ( "#<couleur nom=\"(orange|noir|marron|olive|vertf|marine|jaune|violet|bleugris|argent|gris|rouge|vertc|bleu|rose|turquoise|blanc)\">(.+)</couleur>#sU" , "<span class=\"$1\">$2</span>" , $texte );


            ////////////////////
            // Smilies
            ////////////////////
            $texte = preg_replace ( "#(\s):\)(\s)#"      , " <img src=\"themes/commun/images/smilies/01.png\" title=\":)\" alt=\":)\" /> "             , $texte );
            $texte = preg_replace ( "#(\s):-\)(\s)#"     , " <img src=\"themes/commun/images/smilies/01.png\" title=\":-)\" alt=\":-)\" /> "           , $texte );
            $texte = preg_replace ( "#(\s):D(\s)#"       , " <img src=\"themes/commun/images/smilies/02.png\" title=\":D\" alt=\":D\" /> "             , $texte );
            $texte = preg_replace ( "#(\s);\)(\s)#"      , " <img src=\"themes/commun/images/smilies/03.png\" title=\";)\" alt=\";)\" /> "             , $texte );
            $texte = preg_replace ( "#(\s):p(\s)#"       , " <img src=\"themes/commun/images/smilies/04.png\" title=\":p\" alt=\":p\" /> "             , $texte );
            $texte = preg_replace ( "#(\s):lol:(\s)#"    , " <img src=\"themes/commun/images/smilies/05.gif\" title=\":lol:\" alt=\":lol:\" /> "       , $texte );
            $texte = preg_replace ( "#(\s):euh:(\s)#"    , " <img src=\"themes/commun/images/smilies/06.gif\" title=\":euh:\" alt=\":euh:\" /> "       , $texte );
            $texte = preg_replace ( "#(\s):\((\s)#"      , " <img src=\"themes/commun/images/smilies/07.png\" title=\":(\" alt=\":(\" /> "             , $texte );
            $texte = preg_replace ( "#(\s):o(\s)#"       , " <img src=\"themes/commun/images/smilies/08.png\" title=\":o\" alt=\":o\" /> "             , $texte );
            $texte = preg_replace ( "#(\s):colere:(\s)#" , " <img src=\"themes/commun/images/smilies/09.png\" title=\":colere:\" alt=\":colere:\" /> " , $texte );
            $texte = preg_replace ( "#(\s)o_O(\s)#"      , " <img src=\"themes/commun/images/smilies/10.gif\" title=\"o_O\" alt=\"o_O\" /> "           , $texte );
            $texte = preg_replace ( "#(\s)\^\^(\s)#"     , " <img src=\"themes/commun/images/smilies/11.png\" title=\"^^\" alt=\"^^\" /> "             , $texte );
            $texte = preg_replace ( "#(\s):-°(\s)#"      , " <img src=\"themes/commun/images/smilies/12.png\" title=\":-°\" alt=\":-°\" /> "           , $texte );
            $texte = preg_replace ( "#(\s):'\((\s)#"     , " <img src=\"themes/commun/images/smilies/13.png\" title=\":'(\" alt=\":'(\" /> "           , $texte );

            $texte = str_replace ( '&gt;_&lt;' , '>_<' , $texte );
            $texte = preg_replace ( "#(\s)>_<(\s)#", " <img src=\"themes/commun/images/smilies/14.png\" title=\">_<\" alt=\">_<\" /> "           , $texte );


            ////////////////////
            // Code
            ////////////////////
            if ( preg_match ( "#<code type=\"(.+)\">(.+)</code>#sU" , $texte ) )
            {
                // On remplace les balises <code-$time> qui servent à remplacer les balises <code type=$1>
                $texte = str_replace ( "<code-" . $time . ">" , "<code_" . $time . ">" , $texte );

                // On compte le nombre de sections "code"
                preg_replace ( "#<code type=\"(.+)\">(.+)</code>#sU" , "<code type=\"$1\">2</code>" , $texte , -1 , $nbr );

                // On crée deux tableaux pour stocker le type et le texte du code
                $code_text = array ();
                $code_type = array ();

                for ( $i = 0 ; $i < $nbr ; $i++ )
                {
                    $code_text[$i] = preg_replace ( "#^(.{0,})<code type=\"(.+)\">(.+)</code>(.{0,})$#sU" , "$3" , $texte , 1 );
                    $code_type[$i] = preg_replace ( "#^(.{0,})<code type=\"(.+)\">(.+)</code>(.{0,})$#sU" , "$2" , $texte , 1 );
                    $texte = preg_replace ( "#^(.{0,})<code type=\"(.+)\">(.+)</code>(.{0,})$#sU" , "$1<code-" . $time . ">$4" , $texte , 1 );
                }

                for ( $i = 0 ; $i < $nbr ; $i++ )
                {
                    // On remplace tous les chevrons
                    $code_text[$i] = str_replace ( '&lt;' , '<' , $code_text[$i] );
                    $code_text[$i] = str_replace ( '&gt;' , '>' , $code_text[$i] );

                    $geshi =& new GeSHi ( $code_text[$i] , $code_type[$i] );
                    $geshi->set_header_type ( GESHI_HEADER_NONE );
                    $parse = $geshi->parse_code ();

                    $parse = str_replace ( "\n" , '' , $parse );

                    $texte = preg_replace ( "#<code-" . $time . ">#" , "<span class=\"code\">Code : " . $code_type[$i] . "</span><div class=\"codetexte\">" . $parse . "</div>" , $texte , 1 );
                }
            }


            ////////////////////
            // Espaces insécables
            ////////////////////
            $texte = preg_replace ( "# (:|;|!|\?)#" , "&nbsp;$1" , $texte );


            ////////////////////
            // Retours à la ligne
            ////////////////////
            $texte = preg_replace ( "#\n#" , "<br/>" , $texte );

            $texte = preg_replace ( "#<ul>#" , "<ul>\n" , $texte );
            $texte = preg_replace ( "#</li>#" , "</li>\n" , $texte );

            $texte = preg_replace ( "#((\<br[/]{0,1}\>)+)<h([23456]{1})>#U" , "\n<h$3>", $texte );
            $texte = preg_replace ( "#</h([23456]{1})>((\<br[/]{0,1}\>)+)#U" , "</h$1>\n", $texte );

            $texte = preg_replace ( "#<br[/]{0,1}>#", "<br/>\n", $texte );

            return $texte;
        }
    }


    /*****************************************
     * void Site->CreateImageEmail ( unsigned int $id , string $email , bool $messagerie = false )
     *
     * Crée une image contenant l'adresse e-mail d'un membre
     *
     *  $id : identifiant du membre
     *  $email : adresse e-mail du membre
     *  $messagerie : indique s'il s'agit de l'adresse de messagerie
     ****************************************/

    function CreateImageEmail ( $id , $email , $messagerie = false )
    {
        $largeur = ( strlen ( $email ) * 10 ) - 4;

        $image = imagecreate ( $largeur , 20 );

        $blanc = imagecolorallocate ( $image , 255, 255 , 255 );
        $noir = imagecolorallocate ( $image , 0 , 0 , 0 );

        imagestring ( $image , 6 , ( strlen ( $email ) / 2 ) - 2 , 2 , $email , $noir );
        imagecolortransparent ( $image , $blanc );

        if ( $messagerie )
        {
            imagepng ( $image , 'fichiers/membres/msg-' . $id . '.png' );
        }
        else
        {
            imagepng ( $image , 'fichiers/membres/' . $id . '.png' );
        }
    }


    /*****************************************
     * string Site->ConvertTaille ( unsigned int $taille , string $unite = 'Kio' )
     *
     * Simplifie une taille en octets en multiples
     *
     *  $taille : taille du fichier
     *  $unite : Kio ou Ko
     *
     *  Retour : chaine contenant la taille du fichier et l'unité
     ****************************************/

    function ConvertTaille ( $taille , $unite = 'Kio' )
    {
        if ( $unite == 'Kio' )
        {
            if ( $taille < 1024 ) return $taille . ' octets';
            if ( $taille === 1024 ) return '1 Kio';
            if ( $taille < 1048576 ) return round ( $taille / 1024 , 1 ) . ' Kio';
            if ( $taille === 1048576 ) return '1 Mio';
            if ( $taille < 1073741824 ) return round ( $taille / 1048576 , 1 ) . ' Mio';
            if ( $taille === 1073741824 ) return '1 Gio';
            if ( $taille < 1099511627776 ) return round ( $taille / 1073741824 , 1 ) . ' Gio';
            if ( $taille === 1099511627776 ) return '1 Tio';
        }
        else if ( $unite == 'Ko' )
        {
            if ( $taille < 1000 ) return $taille . ' octets';
            if ( $taille === 1000 ) return '1 Ko';
            if ( $taille < 1000000 ) return round ( $taille / 1000 , 1 ) . ' Ko';
            if ( $taille === 1000000 ) return '1 Mo';
            if ( $taille < 1000000000 ) return round ( $taille / 1000000 , 1 ) . ' Mo';
            if ( $taille === 1000000000 ) return '1 Go';
            if ( $taille < 1000000000000 ) return round ( $taille / 1000000000 , 1 ) . ' Go';
            if ( $taille === 1000000000000 ) return '1 To';
        }

        return $taille . ' octets';
    }
}


/*****************************************
 * string ConvertDate ( string $date )
 *
 * Simplifie une taille en octets en multiples
 *
 *  $date : date au format SQL date
 *
 *  Retour : chaine contenant la date au format d/m/Y
 ****************************************/

function ConvertDate ( $date )
{
    $date = explode ( '-' , $date );

    $jour = $date[2];
    $mois = $date[1];
    $annee = $date[0];

    return $jour . '/' . $mois . '/' . $annee;
}


function ConvertIP ( $in , $out )
{
    if ( empty ( $in ) && empty ( $out ) )
    {
        return false;
    }

    // Conversion d'un entier en adresse IP
    if ( empty ( $in ) )
    {
        $ip = $out;

        if ( !preg_match ( "#^[0-9]{1,10}$#" , $ip ) )
        {
            return false;
        }
        
        if ( $ip < 0 || $ip > 4294967295 )
        {
            return false;
        }

        $ip_explode[3] = $ip % 256;
        $ip -= $ip_explode[3];
        $ip_explode[2] = ( $ip / 256 ) % 256;
        $ip -= $ip_explode[2] * 256;
        $ip_explode[1] = ( $ip / ( 256 * 256 ) ) % 256;
        $ip -= $ip_explode[1] * 256 * 256;
        $ip_explode[0] = ( $ip / ( 256 * 256 * 256 ) ) % 256;

        return $ip_explode[0] . '.' . $ip_explode[1] . '.' . $ip_explode[2] . '.' . $ip_explode[3];
    }
    // Conversion d'une adresse IP en entier
    else
    {
        $ip = $in;

        if ( !preg_match ( "#^[0-9]{1,3}.[0-9]{1,3}.[0-9]{1,3}.[0-9]{1,3}$#" , $ip ) )
        {
            return false;
        }

        $ip_explode = explode ( '.' , $ip );

        for ( $i = 0 ; $i < 4 ; $i++ )
        {
            if ( $ip_explode[$i] < 0 || $ip_explode[$i] > 255 )
            {
                return false;
            }
        }

        $ip = 256 * 256 * 256 * $ip_explode[0] + 256 * 256 * $ip_explode[1] + 256 * $ip_explode[2] + $ip_explode[3];
    }

    return $ip;
}


function SendEmail ( $destinataire , $auteur , $sujet , $texte )
{
    // Séparation des différentes partie de l'e-mail
    $multipart = md5 ( mt_rand () );

    // En-tête de l'email
    $entete = "MIME-Version: 1.0\r\nFrom: " . $auteur . "\r\nReply-to: " . $auteur . "\r\nX-Sender: " . $auteur . "\r\nX-Mailer: " . $auteur . "\r\nX-auth-smtp-user: " . $auteur . "\r\nX-abuse-contact: " . $auteur . "\r\nContent-Type: multipart/related; boundary=\"" . $multipart . '"';


    $contenu = "\r\n--" . $multipart . "--\r\n";
    //$contenu .= 'Content-Type: multipart/alternative; boundary="' . $multipart2 . "\"\r\n";
    //$contenu .= "This is a multi-part message in MIME format.\r\n\r\n";
    //$contenu .= '--' . $multipart2 . "\r\n";
    $contenu .= "Content-Transfer-Encoding: 8bit\r\n";
    $contenu .= "Content-Type: text/plain; charset=utf-8\r\n\r\n";

    $txt = preg_replace ( "#<a href=\"(.+)\">(.+)</a>#isU" , "$2" , $texte );

    $txt = str_replace ( '<br />' , '' , $txt );
    $txt = str_replace ( '<h1>' , '' , $txt );
    $txt = str_replace ( '</h1>' , '' , $txt );
    $txt = str_replace ( '<p>' , '' , $txt );
    $txt = str_replace ( '</p>' , '' , $txt );
    $txt = str_replace ( '<strong>' , '' , $txt );
    $txt = str_replace ( '</strong>' , '' , $txt );
    $txt = str_replace ( '<em>' , '' , $txt );
    $txt = str_replace ( '</em>' , '' , $txt );

    $contenu .= $txt;

    $contenu .= "\r\n\r\n--" . $multipart . "--\r\n";
    $contenu .= "Content-Transfer-Encoding: 8bit\r\n";
    $contenu .= "Content-Type: text/html; charset=utf-8\r\n\r\n";
    $contenu .= "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"fr\">\n\n<head>\n<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />\n<meta http-equiv=\"pragma\" content=\"no-cache\" />\n<title>" . $sujet . "</title>\n\n</head>\n\n<body>\n\n";
    $contenu .= $texte;
    $contenu .= "\n\n</body>\n\n</html>";
    $contenu .= "\r\n\r\n--" . $multipart . "--\r\n";
    //$contenu .= "\r\n--" .  $multipart1 . "\r\n";


    // Envoi de l'e-mail
    return mail ( $destinataire , $sujet , $contenu , $entete );
}


function CryptMdp ( $mdp )
{
    if ( sizeof ( $mdp ) > 16 )
    {
        return false;
    }

    //$mdp = sha1 ( $mdp );
    $mdp = md5 ( $mdp );

    return $mdp;
}

?>