<?php
/***************************************************************************
 *  Copyright (C) 2007 Michel Teddy
 *  This file is part of Tagadash
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published
 *  by the Free Software Foundation; either version 2.1 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 ***************************************************************************/
/***************************************************************************
 *  Fichier : /systeme/lib_php5/db_mysql.php
 *  Date de création : 12/08/2007
 *  Dernière modification : 14/09/2007
 ***************************************************************************/

// Sécurité
if ( !defined ( 'TAGADASH' ) )
{
    header ( 'Location: ../' );
    die ( -1 );
}


// Inclusion du fichier de la classe Database
if ( is_file ( 'systeme/lib_php5/database.' . EXT ) )
{
    include_once ( 'systeme/lib_php5/database.' . EXT );
}
else
{
    die ( 'Le fichier systeme/lib_php5/database.' . EXT . ' est introuvable.' );
}


/*
 * Méthodes publiques de la classe Database :
 *
 *  __construct ( void )
 *  void SetParametres ( string $Hote , string $User , string $Pass , string $Base = '' , string $Pref = '' )
 *
 * Méthodes publiques de la classe fille :
 *
 *  __construct ( void )
 *  __destruct ()
 *
 *  bool Connect ( void )
 *  bool Disconnect ( void )
 *  void Erreur ( unsigned int $ligne , string $fichier , string $requete )
 *  ressource Requete ( string $requete )
 *  unsigned int LastInsertId ( ressource $requete )
 *  unsigned int NbrRowsSelected ( ressource $requete )
 *  unsigned int NbrRowsAffected ( ressource $requete )
 *  array Result ( ressource $requete , string $champ , int $ligne = 0 )
 *  array ResultArray ( ressource $requete )
 *  string Protege ( string $texte , bool $stripslashes = true )
 *  string Version ( void )
 *
 **/


class MySQL extends Database
{
    /*****************************************
     * MySQL->__construct ( void )
     *
     * Constructeur de la classe.
     * Modifie les paramètres et se connecte à la base de données
     ****************************************/

    public function __construct ()
    {
        parent::__construct ();

        $this->Connect ();
    }


    /*****************************************
     * MySQL->__destruct ()
     *
     * Déstructeur de la classe.
     * Se déconnecte du serveur
     ****************************************/

    public function __destruct ()
    {
        $this->Disconnect ();
    }


    /*****************************************
     * bool MySQL->Connect ( void )
     *
     * Connexion à la base de données
     *
     *  Retour : booléen indiquant le succès de l'opération
     ****************************************/

    public function Connect ()
    {
        $id = mysql_connect ( $this->hote , $this->user , $this->pass );

        if ( $id === false )
        {
            return false;
        }

        $this->link = $id;

        if ( !mysql_select_db ( $this->base , $this->link ) )
        {
            if ( !mysql_query ( "CREATE DATABASE `" . $this->base . "`;" , $this->link ) )
            {
                return false;
            }
        }

        $this->connected = true;

        return true;
    }


    /*****************************************
     * bool MySQL->Disconnect ( void )
     *
     * Déconnexion de la base de données
     *
     *  Retour : booléen indiquant le succès de l'opération
     ****************************************/

    public function Disconnect ()
    {
        if ( $this->connected )
        {
            $this->connected = false;

            $close = mysql_close ( $this->link );

            $this->link = 0;

            return $close;
        }

        return false;
    }


    /*****************************************
     * void MySQL->Erreur ( unsigned int $ligne , string $fichier , string $requete )
     *
     * Affichage d'une erreur
     *
     *  $ligne : ligne du fichier où s'effectue la requête (obtenue par __LINE__)
     *  $fichier : fichier où s'effectue la requête (obtenue par __FILE__)
     *  $requete : requête SQL exécutée
     ****************************************/

    public function Erreur ( $ligne , $fichier , $requete )
    {
        global $configuration;
        global $site;
        global $langue;

        $page_titre = 'Erreur MySQL';
        $page_simple = 1;
        $page_CSS = '';


        // On enlève les espaces en début de ligne
        $requete = preg_replace ( "#\n(\s{0,})#" , "\n" , $requete );

        // Pour la coloration de la requête SQL
        if ( function_exists ( 'geshi_highlight' ) )
        {
            $requete = geshi_highlight ( $requete , 'mysql' , null , true );
        }

        // Suppression des retours à la ligne
        #$requete = preg_replace ( "#\n#" , " " , $requete );


        // Transformation du message d'erreur

        $erreur = mysql_error ( $this->link );

        $erreur = preg_replace ( "#^Duplicate entry '(.+)' for key 1$#is" , "L'entrée <q>$1</q> existe déjà" , $erreur );

        $erreur = preg_replace ( "#^Access denied for user '(.+)'@'(.+)' \(using password: NO\)$#is" , "Accès refusé pour l'utilisateur $1@$2 (pas de mot de passe)" , $erreur );

        $erreur = preg_replace ( "#^You have an error in your SQL syntax; check the manual that corresponds to your MySQL server version for the right syntax to use near '(.+)' at line (.+)$#is" , "La syntaxe de la requête est incorrecte près de <q>$1</q>, à la ligne $2" , $erreur );
        #$erreur = preg_replace ( "#^You have an error in your SQL syntax; check the manual that corresponds to your MySQL server version for the right syntax to use near '(.+)' at line (.+)$#is" , "La syntaxe de la requête est incorrecte près de <q>$1</q>" , $erreur );

        //1048
        $erreur = preg_replace ( "#^Column '(.+)' cannot be null$#is" , "La colonne <q>$1</q> ne peut pas être nulle" , $erreur );

        //1052
        $erreur = preg_replace ( "#^Column '(.+)' in where clause is ambiguous$#is" , "La colonne <q>$1</q> dans la clause WHERE est ambigüe" , $erreur );
        $erreur = preg_replace ( "#^Column '(.+)' in field list is ambiguous$#is" , "La colonne <q>$1</q> dans la liste des champs est ambigüe" , $erreur );

        //1054
        $erreur = preg_replace ( "#^Unknown column '(.+)' in 'field list'$#is" , "La colonne <q>$1</q> est inconnue dans la liste des champs" , $erreur );
        $erreur = preg_replace ( "#^Unknown column '(.+)' in 'on clause'$#is" , "La colonne <q>$1</q> est inconnue dans la clause ON" , $erreur );
        $erreur = preg_replace ( "#^Unknown column '(.+)' in 'order clause'$#is" , "La colonne <q>$1</q> est inconnue dans la clause ORDER" , $erreur );
        $erreur = preg_replace ( "#^Unknown column '(.+)' in 'where clause'$#is" , "La colonne <q>$1</q> est inconnue dans la clause WHERE" , $erreur );

        //1062
        $erreur = preg_replace ( "#^Duplicate entry '(.+)' for key (.+)$#is" , "L'entrée <q>$1</q> existe déjà pour la clé unique <q>$2</q>" , $erreur );

        //1065
        $erreur = preg_replace ( "#^Query was empty$#i" , "La requête est vide" , $erreur );

        //1066
        $erreur = preg_replace ( "#^Not unique table/alias: '(.+)'$#is" , "Vous utilisez plusieurs fois la table <q>$1</q>" , $erreur );

        //1103
        $erreur = preg_replace ( "#^Incorrect table name '(.{0,})'$#is" , "Le nom de la table est incorrect : <q>$1</q>" , $erreur );

        //1146
        $erreur = preg_replace ( "#^Table '(.+)' doesn't exist$#is" , "La table <q>$1</q> n'existe pas" , $erreur );

        //1227
        $erreur = preg_replace ( "#^Access denied; you need the SHOW DATABASES privilege for this operation$#is" , "Accès refusé, vous devez avoir le privilège pour voir les bases de données" , $erreur );

        //2006
        $erreur = preg_replace ( "#^MySQL server has gone away$#is" , "MySQL server has gone away" , $erreur );


        $page_texte = '<p><strong>Erreur&nbsp;:</strong> ' . $erreur . " (Erreur " . mysql_errno ( $this->link ) . ")</p>\n";
        $page_texte .= '<p><strong>Date et heure&nbsp;:</strong> ' . date ( $configuration['format_date'] ) . ' à ' . date ( $configuration['format_heure'] ) . "</p>\n";
        $page_texte .= '<p><strong>Fichier&nbsp;:</strong> ' . $fichier . " (Ligne " . $ligne . ")</p>\n";
        $page_texte .= "<p><strong>Requête SQL&nbsp;:</strong></p>\n<div id=\"query\"><code>" . $requete . "</code></div>\n\n";

        $page_texte .= "<p>Retour à la <a href=\"index." . EXT . "\" title=\"Retourner sur la page d'accueil\">page d'accueil</a>.</p>";

        include ( 'systeme/page.' . EXT );

        die ( -1 );
    }


    /*****************************************
     * ressource MySQL->Requete ( string $requete )
     *
     * Exécute une requête SQL
     *
     *  $requete : requête SQL à exécuter
     *
     *  Retour : résultat de la requête ou false en cas d'échec
     ****************************************/

    public function Requete ( $requete )
    {
        if ( !$this->connected )
        {
            return false;
        }

        // Temps d'exécution
        $tps_requetes = microtime ( true );

        $req = mysql_query ( $requete , $this->link );

        $this->tps_requetes += microtime ( true ) - $tps_requetes;
        $this->nbr_requetes++;

        return $req;
    }


    public function Requete2 ( $requete , $ligne = 0 , $fichier = '' )
    {
        if ( !$this->connected )
        {
            return false;
        }

        // Temps d'exécution
        $tps_requetes = microtime ( true );

        $req = mysql_query ( $requete , $this->link );

        $this->tps_requetes += microtime ( true ) - $tps_requetes;
        $this->nbr_requetes++;

        if ( $req === false )
        {
            $this->Erreur ( __LINE__ , __FILE__ , $sql );
        }

        return $req;
    }


    /*****************************************
     * unsigned int MySQL->LastInsertId ( ressource $requete )
     *
     * Dernier identifiant entré dans la base
     *
     *  $requete : requête concernée
     *
     *  Retour : numéro du dernier id entré dans la base
     ****************************************/

    public function LastInsertId ( $requete )
    {
        return mysql_insert_id ( $this->link );
    }


    /*****************************************
     * unsigned int MySQL->NbrRowsSelected ( ressource $requete )
     *
     * Compte le nombre de lignes sélectionnées par une requête Select.
     *
     *  $requete : requête à analyser
     *
     *  Retour : nombre de ligne sélectionnées
     ****************************************/

    public function NbrRowsSelected ( $requete )
    {
        return mysql_num_rows ( $requete );
    }


    /*****************************************
     * unsigned int MySQL->NbrRowsAffected ( ressource $requete )
     *
     * Compte le nombre de lignes affectées par une requête de type Update ou Delete.
     *
     *  $requete : requête à analyser
     *
     *  Retour : nombre de ligne affectées par une requêtes
     ****************************************/

    public function NbrRowsAffected ( $requete )
    {
        return mysql_affected_rows ( $this->link );
    }

    /*****************************************
     * array MySQL->Result ( ressource $requete , string $champ , unsigned int $ligne = 0 )
     *
     * Retourne le résultat d'une requête Select
     *
     *  $requete : requête à analyser
     *  $champ : champ à sélectionner
     *  $ligne : ligne à sélectionner
     *
     *  Retour : nombre de ligne affectées par une requêtes
     ****************************************/

    public function Result ( $requete , $champ , $ligne = 0 )
    {
        for ( $i = 0 ; $row = $this->ResultArray ( $requete ) ; $i++ )
        {
            if ( $ligne == $i ) return $row[$champ];
        }
    }


    /*****************************************
     * array MySQL->ResultArray ( ressource $requete )
     *
     * Retourne le résultat d'une requête Select sous forme d'un tableau
     *  pour chaque ligne de résultat.
     *
     *  $requete : requête à analyser
     *
     *  Retour : tableau contenant une ligne de la requête
     ****************************************/

    public function ResultArray ( $requete )
    {
        return mysql_fetch_assoc ( $requete );
    }


    /*****************************************
     * array MySQL->ResultArray2 ( ressource $requete )
     *
     * Retourne le résultat d'une requête Select sous forme d'un tableau
     *  à deux dimensions (lignes et colonnes).
     *
     *  $requete : requête à analyser
     *
     *  Retour : tableau contenant les résultats de la requête
     ****************************************/

    public function ResultArray2 ( $requete )
    {
        $result = array ();

        while ( $row = mysql_fetch_assoc ( $requete ) )
        {
            $result[] = $row;
        }

        return $result;
    }


    /*****************************************
     * string MySQL->Protege ( string $texte , bool $stripslashes = true )
     *
     * Protège du texte contre les injections SQL
     *
     *  $texte : texte à transformer
     *  $stripslashes : indique si on doit supprimer les slashes
     *
     *  Retour : texte transformé
     ****************************************/

    public function Protege ( $texte , $stripslashes = true )
    {
        if ( $stripslashes && get_magic_quotes_gpc () == 1 )
        {
            $texte = stripslashes ( $texte );
        }

        return mysql_real_escape_string ( $texte );
    }


    /*****************************************
     * string MySQL->Version ( void )
     *
     * Donne la version de MySQL
     *
     *  Retour : version de MySQL
     ****************************************/

    public function Version ()
    {
        return mysql_get_server_info ();
    }
}

?>