<?php
/***************************************************************************
 *  Copyright (C) 2007 Michel Teddy
 *  This file is part of Tagadash
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published
 *  by the Free Software Foundation; either version 2.1 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 ***************************************************************************/
/***************************************************************************
 *  Fichier : /systeme/lib_php5/db_pgsql.php
 *  Date de création : 04/09/2007
 *  Dernière modification : 14/09/2007
 ***************************************************************************/

// Sécurité
if ( !defined ( 'TAGADASH' ) )
{
    header ( 'Location: ../' );
    die ( -1 );
}


// Inclusion du fichier de la classe Database
if ( is_file ( 'systeme/lib_php5/database.' . EXT ) )
{
    include_once ( 'systeme/lib_php5/database.' . EXT );
}
else
{
    die ( 'Le fichier systeme/lib_php5/database.' . EXT . ' est introuvable.' );
}


/*
 * Méthodes publiques de la classe Database :
 *
 *  __construct ( void )
 *  void SetParametres ( string $Hote , string $User , string $Pass , string $Base = '' , string $Pref = '' )
 *
 * Méthodes publiques de la classe fille :
 *
 *  __construct ( void )
 *  __destruct ()
 *
 *  bool Connect ( void )
 *  bool Disconnect ( void )
 *  void Erreur ( unsigned int $ligne , string $fichier , string $requete )
 *  ressource Requete ( string $requete )
 *  unsigned int LastInsertId ( ressource $requete )
 *  unsigned int NbrRowsSelected ( ressource $requete )
 *  unsigned int NbrRowsAffected ( ressource $requete )
 *  array Result ( ressource $requete , string $champ , int $ligne = 0 )
 *  array ResultArray ( ressource $requete )
 *  string Protege ( string $texte , bool $stripslashes = true )
 *  string Version ( void )
 *
 **/


class PostgreSQL extends Database
{
    /*****************************************
     * PostgreSQL->__construct ( void )
     *
     * Constructeur de la classe.
     * Modifie les paramètres et se connecte à la base de données
     ****************************************/

    public function __construct ()
    {
        parent::__construct ();

        $this->Connect ();
    }


    /*****************************************
     * PostgreSQL->__destruct ()
     *
     * Déstructeur de la classe.
     * Se déconnecte du serveur
     ****************************************/

    public function __destruct ()
    {
        $this->Disconnect ();
    }


    /*****************************************
     * bool PostgreSQL->Connect ( void )
     *
     * Connexion à la base de données
     *
     *  Retour : booléen indiquant le succès de l'opération
     ****************************************/

    public function Connect ()
    {
        $id = pg_connect ( 'host=' . $this->hote . ' port=5432 dbname=' . $this->base . ' user=' . $this->user . ' password=' . $this->pass );

        if ( $id === false )
        {
            return false;
        }

        $this->connected = true;

        $this->link = $id;

        return true;
    }


    /*****************************************
     * bool PostgreSQL->Disconnect ( void )
     *
     * Déconnexion de la base de données
     *
     *  Retour : booléen indiquant le succès de l'opération
     ****************************************/

    public function Disconnect ()
    {
        if ( $this->connected )
        {
            return pg_close ( $this->link );
        }

        return false;
    }


    /*****************************************
     * void PostgreSQL->Erreur ( unsigned int $ligne , string $fichier , string $requete )
     *
     * Affichage d'une erreur
     *
     *  $ligne : ligne du fichier où s'effectue la requête (obtenue par __LINE__)
     *  $fichier : fichier où s'effectue la requête (obtenue par __FILE__)
     *  $requete : requête SQL exécutée
     ****************************************/

    public function Erreur ( $ligne , $fichier , $requete )
    {
        global $configuration;
        global $site;

        $page_titre = 'Erreur PostgreSQL';
        $page_simple = 1;


        // On enlève les espaces en début de ligne
        $requete = preg_replace ( "#\n(\s{0,})#" , "\n" , $requete );

        // Pour la coloration de la requête SQL
        if ( function_exists ( geshi_highlight ) )
        {
            $requete = geshi_highlight ( $requete , 'mysql' , null , true );
        }

        // Suppression des retours à la ligne
        #$requete = preg_replace ( "#\n#" , " " , $requete );


        $page_texte = "<p><strong>Erreur :</strong> <pre>" . pg_last_error ( $this->link ) . "</pre></p>\n";
        $page_texte .= '<p><strong>Date et heure :</strong> ' . date ( $configuration['format_date'] ) . ' à ' . date ( $configuration['format_heure'] ) . "</p>\n";
        $page_texte .= "<p><strong>Fichier :</strong> " . $fichier . " (Ligne " . $ligne . ")</p>\n";
        $page_texte .= "<p><strong>Requête SQL :</strong></p>\n<div id=\"query\"><code>" . $requete . "</code></div>\n";

        $page_texte .= "<p>Retour à la <a href=\"index." . EXT . "\" title=\"Retourner sur la page d'accueil\">page d'accueil</a>.</p>";

        include ( 'systeme/page.' . EXT );

        die ( -1 );
    }


    /*****************************************
     * ressource PostgreSQL->Requete ( string $requete )
     *
     * Exécute une requête SQL
     *
     *  $requete : requête SQL à exécuter
     *
     *  Retour : résultat de la requête ou false en cas d'échec
     ****************************************/

    public function Requete ( $requete )
    {
        if ( !$this->connected )
        {
            return false;
        }

        $requete = str_replace ( '`' , '' , $requete );

        // Temps d'exécution
        $tps_requetes = microtime ( true );

        $req = pg_query ( $this->link , $requete );

        $this->tps_requetes += microtime ( true ) - $tps_requetes;
        $this->nbr_requetes++;

        return $req;
    }


    /*****************************************
     * unsigned int PostgreSQL->LastInsertId ( ressource $requete )
     *
     * Dernier id inséré.
     *
     *  $requete : requête à analyser
     *
     *  Retour : numéro du dernier id entré dans la base
     ****************************************/

    public function LastInsertId ( $requete)
    {
        return pg_last_oid ( $requete );
    }


    /*****************************************
     * unsigned int PostgreSQL->NbrRowsSelected ( ressource $requete )
     *
     * Compte le nombre de lignes sélectionnées par une requête Select.
     *
     *  $requete : requête à analyser
     *
     *  Retour : nombre de ligne sélectionnées
     ****************************************/

    public function NbrRowsSelected ( $requete )
    {
        return pg_num_rows ( $requete );
    }


    /*****************************************
     * unsigned int PostgreSQL->NbrRowsAffected ( ressource $requete )
     *
     * Compte le nombre de lignes affectées par une requête de type Update ou Delete.
     *
     *  $requete : requête à analyser
     *
     *  Retour : nombre de ligne affectées par une requêtes
     ****************************************/

    public function NbrRowsAffected ( $requete )
    {
        return pg_affected_rows ( $requete );
    }

    /*****************************************
     * array PostgreSQL->Result ( ressource $requete , string $champ , unsigned int $ligne = 0 )
     *
     * Retourne le résultat d'une requête Select
     *
     *  $requete : requête à analyser
     *  $champ : champ à sélectionner
     *  $ligne : ligne à sélectionner
     *
     *  Retour : nombre de ligne affectées par une requêtes
     ****************************************/

    public function Result ( $requete , $champ , $ligne = 0 )
    {
        for ( $i = 0 ; $row = $this->ResultArray ( $requete ) ; $i++ )
        {
            if ( $ligne == $i ) return $row[$champ];
        }
    }


    /*****************************************
     * array PostgreSQL->ResultArray ( ressource $requete )
     *
     * Retourne le résultat d'une requête Select sous forme de tableau.
     *
     *  $requete : requête à analyser
     *
     *  Retour : nombre de ligne affectées par une requêtes
     ****************************************/

    public function ResultArray ( $requete )
    {
        return pg_fetch_assoc ( $requete );
    }


    /*****************************************
     * string PostgreSQL->Protege ( string $texte , bool $stripslashes = true )
     *
     * Protège du texte contre les injections SQL
     *
     *  $texte : texte à transformer
     *  $stripslashes : indique si on doit enlever les slashes
     *
     *  Retour : texte transformé
     ****************************************/

    public function Protege ( $texte , $stripslashes = true )
    {
        if ( $stripslashes && get_magic_quotes_gpc () )
        {
            $texte = stripslashes ( $texte );
        }

        return pg_escape_string ( $texte );
    }


    /*****************************************
     * string PostgreSQL->Version ( void )
     *
     * Donne la version de MySQL
     *
     *  Retour : version de MySQL
     ****************************************/

    public function Version ()
    {
        $version = pg_version ();
        // Tableau : client, protocol, server_version

        return $version['client'];
    }
}

?>